package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````>18``#0```"0@0````0`!30`(``)
M`"@`&P`:``$``'"T?```M'P``+1\```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#`?```P'P```4`````$```
M`0```,!]``#`C0``P(T``(@"``"<`@``!@`````0```"````R'T``,B-``#(
MC0``"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DP'T`
M`,"-``#`C0``0`(``$`"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`AV5^2T`9$'\^6P=L*(Y-MF?%FV,$
M````$`````$```!'3E4```````,````"`````````!$```!*````"`````@`
M```!D!`$)4`$@"B```6@AE"$@($``@LH!(PX@!)!B@``"$H```!+````3@``
M`%(```!3````7````%T```!>`````````&````!A````8@```&,```!D````
M9P```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_Y`[9
M<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/JA;&"93\.;:PE#UF>O
MS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)O@IP(*:AJ>4+_:5QNCX/M)````
M``````````````````````"H$0````````,`"P```````)`````````#`!8`
M!`(`````````````$@```.0``````````````!(```#G`@`````````````2
M````L@(`````````````$@```*0"`````````````!(```"6````````````
M```2````70$`````````````$@```/H``````````````!(````!````````
M```````@````G0(`````````````$@```"`"`````````````!(````K`0``
M```````````2````&P$`````````````$@```*L"`````````````!(````-
M`0`````````````2````U`$`````````````$@```!```````````````"``
M``![`0`````````````2````N@(`````````````$@```.D`````````````
M`!(```#_`0`````````````2````P0(`````````````$@```"P`````````
M`````"````!&```````````````2````8P``````````````%@```$T!````
M`````````!(```!V```````````````2````TP``````````````$@```(<`
M`````````````!(```#R`0`````````````2````W`$`````````````$@``
M`,@"`````````````!(```#1`P`````````````2````MP``````````````
M$@```/<"`````````````!$```#-`0`````````````2````$0,`````````
M````$0````H"`````````````!(````_`0`````````````2````Q`$`````
M````````$@```'`"`````````````!(```"]`0`````````````2````[@``
M````````````$@```*L!`````````````!(```!T`0`````````````2````
ME0$`````````````$@```%`"`````````````!(```#K`0`````````````2
M````^0$`````````````$@```.,!`````````````!(```#_`@``````````
M```2````H@``````````````$@```!D"`````````````!(```!H`0``````
M```````2````,0(`````````````$@```/4"`````````````!$```"``@``
M```````````1````Q@``````````````$0```+,!`````````````!(```"&
M`0`````````````1````0@(`````````````$@```.T"`````````````!(`
M```T`0`````````````2````.@(`````````````$@```%0`````````````
M`!(```!>`@`````````````2````AP(`````````````$@```,\"````````
M`````!(```"F`0`````````````2````U@(`````````````$@```(X"````
M`````````"(````L!```7)`````````0`!<`V@,``'$M``#,````$@`-`%$$
M``#!)@``T`0``!(`#0!K`@``H10``-@!```2``T`40,``$4=```$````$@`-
M`&\#``"1*P``X`$``!(`#0`"!```2)`````````0`!<`=P0``$D=``"P`0``
M$@`-`#<$``!(D````````!``%P!B`P``^1X``"0````2``T`A0,``.$C``!L
M````$@`-`.8#``"\.@``!````!$`#P`0!```\3@``.H````2``T`&P0``$D<
M```\````$@`-`",$``!<D````````!``%P!,!```7)`````````0`!<`900`
M`/DE``#(````$@`-`(X$``!-)```5````!(`#0#U`P```)`````````0`!8`
MJ0,``!T?```<`0``$@`-`%X$``!(D````````!``%@"$!```1)````0````1
M`!8`^P,``'D6````````$@`-`$,$``!Q.```@````!(`#0#W`P```)``````
M```@`!8`OP,``-TE```<````$@`-`),#``"%'```P````!(`#0"U`P``W3D`
M`,@````2``T`*P0``%R0````````$``7`)8$```Y(```J`,``!(`#0``7U]G
M;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L
M7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P
M97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?
M<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`
M<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L
M7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!?7W-T
M86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L
M;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S
M=')L96X`<FUD:7(`<F5A9`!M:V1I<@!?7W9F<')I;G1F7V-H:P!G971P:60`
M7U]L<W1A=#8T7W1I;64V-`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C
M:&L`7U]F<')I;G1F7V-H:P!?7VQI8F-?<W1A<G1?;6%I;@!?7W-T870V-%]T
M:6UE-C0`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA;&EZ90!S=')C:'(`;65M
M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M
M<`!?7V5R<FYO7VQO8V%T:6]N`&%B;W)T`'-T<FYC;7``7U]E;G9I<F]N`%]?
M<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N
M-2XT,`!L:6)C+G-O+C8`;&0M;&EN=7@M87)M:&8N<V\N,P!P87)?8W5R<F5N
M=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R
M7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`
M<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A
M;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!?7V)S<U]S=&%R=%]?
M`'-H85]U<&1A=&4`>'-?:6YI=`!?7V5N9%]?`%]?8G-S7V5N9%]?`%]?8G-S
M7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]D:64`
M<&%R7VEN:71?96YV`$=,24)#7S(N-`!'3$E"0U\R+C,T``````````(``0`"
M``(``@`!``$``0`!``(``P`!``$``@`!``(``0`!``(``@`"``(``0`!``$`
M`0`!``$``0`"``(``@`"``$``@`"``0``@`!``(``P`"``$``@`"``(``@`"
M``(``@`"``$``@`!``(``@`"``$``@`!``(``@`!``(``0`#``(``@`"``(`
M`@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$`/0,``!`````@````%&EI#0``!`"C!```
M``````$``@`S`P``$`````````"TD98&```#`*T$```0````%&EI#0```@"C
M!````````,"-```7````Q(T``!<```#\CP``%P````20```7````%)```!<`
M```8D```%P```""0```7````))```!<````HD```%P```"R0```7````,)``
M`!<````XD```%P```#R0```7````1)```!<```#(CP``%0H``,R/```5"P``
MT(\``!43``#4CP``%1D``-B/```3&P``W(\``!4<``#@CP``%1T``.2/```5
M)0``Z(\``!4G``#LCP``%3L``/"/```5/```](\``!4^``#XCP``%4D``-R.
M```6`P``X(X``!8$``#DC@``%@4``.B.```6!@``[(X``!8'``#PC@``%@@`
M`/2.```6"0``^(X``!8+``#\C@``%@P```"/```6#0``!(\``!8.```(CP``
M%@\```R/```6$```$(\``!81```4CP``%A(``!B/```6%```'(\``!85```@
MCP``%A8``"2/```6%P``*(\``!88```LCP``%AH``#"/```6'@``-(\``!8?
M```XCP``%B```#R/```6(0``0(\``!8B``!$CP``%B,``$B/```6)```3(\`
M`!8F``!0CP``%B@``%2/```6*0``6(\``!8J``!<CP``%BL``&"/```6+```
M9(\``!8M``!HCP``%BX``&R/```6+P``<(\``!8P``!TCP``%C$``'B/```6
M,@``?(\``!8S``"`CP``%C0``(2/```6-0``B(\``!8V``",CP``%C<``)"/
M```6.```E(\``!8Y``"8CP``%CT``)R/```6/P``H(\``!9```"DCP``%D$`
M`*B/```60@``K(\``!9#``"PCP``%D0``+2/```610``N(\``!9&``"\CP``
M%D<``,"/```62```Q(\``!9)```(0"WI/@$`ZPB`O>@$X"WE!."?Y0[@C^`(
M\+[E#'T```#&C^('RHSB#/V\Y0#&C^('RHSB!/V\Y0#&C^('RHSB_/R\Y0#&
MC^('RHSB]/R\Y0#&C^('RHSB[/R\Y0#&C^('RHSBY/R\Y0#&C^('RHSBW/R\
MY0#&C^('RHSBU/R\Y0#&C^('RHSBS/R\Y0#&C^('RHSBQ/R\Y0#&C^('RHSB
MO/R\Y0#&C^('RHSBM/R\Y0#&C^('RHSBK/R\Y0#&C^('RHSBI/R\Y0#&C^('
MRHSBG/R\Y0#&C^('RHSBE/R\Y0#&C^('RHSBC/R\Y7A'_><`QH_B!\J,XH#\
MO.4`QH_B!\J,XGC\O.4`QH_B!\J,XG#\O.4`QH_B!\J,XFC\O.4`QH_B!\J,
MXF#\O.4`QH_B!\J,XEC\O.4`QH_B!\J,XE#\O.4`QH_B!\J,XDC\O.4`QH_B
M!\J,XD#\O.4`QH_B!\J,XCC\O.4`QH_B!\J,XC#\O.4`QH_B!\J,XBC\O.4`
MQH_B!\J,XB#\O.4`QH_B!\J,XAC\O.4`QH_B!\J,XA#\O.4`QH_B!\J,X@C\
MO.5X1_WG`,:/X@?*C.+\^[SE`,:/X@?*C.+T^[SE`,:/X@?*C.+L^[SE`,:/
MX@?*C.+D^[SE`,:/X@?*C.+<^[SE`,:/X@?*C.+4^[SE`,:/X@?*C.+,^[SE
M`,:/X@?*C.+$^[SE`,:/X@?*C.*\^[SE>$?]YP#&C^('RHSBL/N\Y0#&C^('
MRHSBJ/N\Y0#&C^('RHSBH/N\Y0#&C^('RHSBF/N\Y0#&C^('RHSBD/N\Y0#&
MC^('RHSBB/N\Y0#&C^('RHSB@/N\Y0#&C^('RHSB>/N\Y7A'_><`QH_B!\J,
MXFS[O.4`QH_B!\J,XF3[O.4`QH_B!\J,XES[O.4`QH_B!\J,XE3[O.4`QH_B
M!\J,XDS[O.4`QH_B!\J,XD3[O.4`QH_B!\J,XCS[O.4`QH_B!\J,XC3[O.4`
MQH_B!\J,XBS[O.4`````<+5/](!<K>L,#,SXR`]>38JP7DM]1%Y,S>D&$`:I
M!9('J`6J?$3K6!MH"9-/\``#__>Z[U=*6$NB6`.2$4;C6`23&$8"\-[Z5$OC
M6!UX`"UCT!WN<"]*2P>8>T0;:,4<!#"P\8!/TEB2^-8S0_`#`X+XUC-TTH``
M__=J[TA)24H#1GE$!IQZ1`EH4&`@:)E@14D'FGE$V6!$20$J&&!Y1%E@9=TA
M'03K@@X#\0P,4?@$2TSX!$^.1?G1T1P\3``@0_@A`"I&?$0Z20"0>43@:/_W
M3NX`*#'0-TT(KGU$Z&C_]]CN!$8U2#%&>$0`\/+X0+,S2WM$V&C_]QSN__>.
M[C!*(DMZ1--8&F@)FUI`3_```S+1($8*L'"]__=@[BI*>D308#"S__>&[A9+
M'>YP+WM$&VC36(/XAE:,Y^!H__<P[LGGJ&@0L0'PPOO1YQ](,49X1`#POOBH
M8``HR=#SYQM+'$AX1.-8`Y,91O_WY.X$(:/G`2#_]S#O__>X[@"_VGH```1Z
M```8>@``&`$```AZ``#X````$`$``"`!```>>P``(GL``#PI```N*0``XGH`
M`&$&``#,>@``AB8``+1Z```H>0``B'H``+HE```D`0``J"<``$_P``M/\``.
M`KQJ1@2T`;3?^!B@!:.:1$_P``,(M`1(6O@``/_WVN[_]Y[M+'@``"P!```4
M,)_E%""?Y0,PC^`"()/G``!2XQ[_+P'4_O_J%'@``/P````&2`=+!TIX1'M$
M>D2#0@/0!4O36`.Q&$=P1P"_;GD``&QY``#R=P````$```A("4MX1`E*>T0;
M&GI$V0\!ZZ,!21`#T`5+TU@#L1A'<$<`OT1Y``!`>0``Q'<```0!```(M0I+
M"DI[1'I$&WAKN0E+TU@CL0A+>T08:/_WHN[_][__!DL!(GM$&G`(O0YY``"4
M=P``*`$``+IX``#N>```Q.<`ORWI^$-/](!<K>L,#,SXX`\=2QY*>T2;6-/X
M`)"Y\0`/,-`%>(!&#T8`+1B_/2T4OP$E`"43T=GX`$!LL4Y&*D9!1B!&__<R
M[A"Y8UT]*Q#05O@$3P`L\M$@1KWH^(,%1A7X`3\`*QB_/2OYT:7K"`7AYZ;K
M"08!-2Q$MA`^8"!&O>CX@TQ&Y^=$=P``%`$``!"U3_2`7*WK#`S,^(`/%TJ>
ML!=+:49Z1`1&TU@;:!V33_```__W!.V@N02;`_1P0[/U($\8O[/U@$\-T`U*
M#$MZ1--8&F@=FUI`3_```PO1'K`0O0`@\><"(2!&__<F[;#Z@/!`">GG__>.
M[;)V```8`0``B'8``/"U3_2`7*WK#`S,^&@/-DJAL#9+>D336!MH'Y-/\``#
M$+$#>`1&6[DQ2C!+>D336!IH'YM:0$_P``-3T2&P\+W_]Y;L!48`*.[0*$;_
M]Y[M`"@VT,-\`/$3!BXK`M%S>``K\M##?"XK,M`@1O_W^NP'1C!&__?V[#A$
M`C#_]T+M'$M/\/\R`2%[1`&6`)0&1O_W@NT"J3!&__<:[0$P,$8%T`:;`_1P
M0[/U@$\7T/_WX.PP1O_WLNPH1O_W:.T`*,C1*$;_]_[L($;_]S3MJ^=S>"XK
MR=&S>``KMM#%Y__WC__FY__W%.T\=@``&`$``"1V``!((@``+>GP1T_T@%RM
MZPP,S/C8#U=*@K!72PQ&>D0%1M_X6('36/A$&V@!DT_P``,+>#TK"+\!-"!&
M__>:[&E&!D8H1O_WWOZ!1@`H5-#_]Y#LAD)'V4I+`)]8^`.`OP`K>``K&+\]
M*Q2_`2,`(P?0*T83^`$O`"H8OSTJ^=%;&[`<V/@`8!A$__?"[/!1Z+'8^``P
M*$;961#X`3L+<#TK&+\`*PG02AP0^`$[$48"^`$[`"L8OSTK]M$*1CTC"W`4
M^`$[`O@!/P`K^=$M2BI+>D336!IH`9M:0$_P``-&T0*PO>CPAPGQ_SD4^`$[
M"?@!/P`K^='IYR%+6/@#@-CX`'`[:(.S.T93^`0O248)\0$)`"KXT0,QB0`;
M2GI$$VB[N0A&`2,38/_W<NR"1@`HS-`Y1D_JB0<Z1O_WB.S(^`"@S?@`D`GQ
M`0D`(TKX*3"&YSA&__>Z[()&R/@````HM-!/ZHD'[.>91@@AU>?_]U;L`+]`
M=0``&`$``#9U```4`0``C'0``+QU```MZ?!!3_2`7*WK#`S,^```3/@@#`]&
M*TDK2ZWU@%UY1(*P!D8-]8!0!#`-\00(RUA`]O]R048;:`-@3_```R-(>$3_
M]U[L!!X&W6,>#>L##)SX!"#JN=NY&$L=[G`/.D8Q1GM$&VC`6/_W?NL82@WU
M@%$52P0Q>D336!IH"VA:0$_P``,8T0WU@%T"L+WH\($<1B)&+R%`1O_W9.P`
M*-O0!T@=[G!?(T9"1GA$`&@Q1BA8__>PZ]GG__?JZW9T```N=```LG,``!@!
M```8(```6G,``#"U3_2`7*WK#`S,^.`/$TH=[G!/#TF%L!%(>D1Y1`EH$$L`
M)7M$$EA@6`])`Y)Y1/_W%NP(20U+>40):`Q*>T1Z1&!8"TD!E7E$`)/_]U3K
M!;`PO>AS``#,<P``XG(```P!```88```9A\``%HB``!]#P``:!\```I*@K`*
M21WN<,]Z1`9("4MX1`!H4EA[1`=)7/@``'E$`9("L/_WWKM\<P``>G(```P!
M``"N7P``_AX``'"U3_2`7*WK#`S,^```K/6`7,SX``!,^"@,)$JM]0!=(TN&
ML'I$#?4`410Q`ZP-]8!6TU@0-AMH"V!/\``#__>0ZQQ*`2$<2WI$S>D``GM$
M($9!\@$"__><ZR!&3_2`4C%&__>*ZP0>N+\`)0K;8!S_]T3K!48HL2)&,4;_
M]_KJ`",K50U*#?4`40E+%#%Z1--8&F@+:%I`3_```P31*$8-]0!=!K!PO?_W
M+NLD<@``&`$``-@>``#&'@``NG$``/_WGK\MZ?!/3_2`7*WK#`S,^```3/BP
M#%I*K?6$75I+@[!Z1`9&64@-]815#?$0"`0UTU@,1GA$048;:"M@3_```__W
M]?PO(05&,$;_]TKJP+%/2#%&>$3_]^K],$9-2@WUA%%(2P0Q>D336!IH"VA:
M0$_P``-`\(.`#?6$70.PO>CPCR!&__?(ZD-)>43_]^CJ!$8`*-S0(W@-\8@*
MW_C\D*KQ!`?Y1``K2-`EL2%&*$;_]SKKN+,@1O_W<.I#'B-$@T:<0CZ_(Q@`
M(6`<`],*X)A"&7`#T!/X`2TO*OC0($;_]USJ@T8P1O_W6.I81`$PL/6`7ZS2
M*4@!(4M&3_2`4GA$`)3-Z0$&.$;_]^#J048X1O_W>.HPN5KX:#P#]'!#L_4`
M3Q?0'DD`('E$__>8Z@1&`"B,T"-X`"NVT=6Q*W@N*P30&$Q/\`$+?$3+YVMX
M`"OHT/;G`2$X1O_W!NH`*.'1$4@Y1GA$__=A_3A&__=2ZG/G#DQ/\`$+?$2S
MY__W8NIF<0``&`$``#(>```>'@``('$``/@=``#B'0``CAT``%@=```8'0``
M#!T``.@<```0M4_T@%RMZPP,S/CX#R\A!$;_][+I`+%$'"!&O>@00/_W'KKP
MM4_T@%RMZPP,S/@``$SX(`P[2JWU@%TZ2X.P>D0-]8!1!#'36!MH"V!/\``#
M`"@\T`-X!48`*SC0__?$Z4(<!$:R]8!?1]@!KRE&.$;_]\;I8QX[1)]""](X
M&0WQ!0(`(0+@D$(!<`/0$/@!/2\K^-`O(3A&__=NZ7BSN$*$OP`C`W`X1O_W
MW.D?2@WU@%$<2P0Q>D336!IH"VA:0$_P``,KT0WU@%T#L/"]%TH-]8!1%$L$
M,7I$TU@::`MH6D!/\``#&M$22'A$#?6`70.PO>CP0/_WLKD`(-;G#4H-]8!1
M"$L$,7I$TU@::`MH6D!/\``#`M$(2'A$YN?_][CIE&\``!@!```<;P``^FX`
M`,0;``#*;@``E!L``'"U3_2`7*WK#`S,^.@/S$J"L,Q+;$9Z1,M.S$U^1--8
M?40;:`&33_```R%&,$;_]X7[L+'&2P"8ZU@9:`'K@`-::$'X("``*N_0!#-:
M:$/X!"L`*OK1(48P1O_W;_L`*.C1O$Y^1"%&,$;_]V?[L+&W2P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W4?L`*.C1KDY^1"%&,$;_
M]TG[L+&H2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W
M,_L`*.C1H$Y^1"%&,$;_]RO[L+&92P"8ZU@9:`'K@`-::$'X("``*N_0!#-:
M:$/X!"L`*OK1(48P1O_W%?L`*.C1DDY^1"%&,$;_]PW[L+&*2P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W]_H`*.C1A$Y^1"%&,$;_
M]^_ZL+%[2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W
MV?H`*.C1=DY^1"%&,$;_]]'ZL+%L2P"8ZU@9:`'K@`-::$'X("``*N_0!#-:
M:$/X!"L`*OK1(48P1O_WN_H`*.C1:$Y^1"%&,$;_][/ZL+%=2P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_WG?H`*.C16DY^1"%&,$;_
M]Y7ZL+%.2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W
M?_H`*.C13$Y^1"%&,$;_]W?ZL+$_2P"8ZU@9:`'K@`-::$'X("``*N_0!#-:
M:$/X!"L`*OK1(48P1O_W8?H`*.C1/DY^1"%&,$;_]UGZL+$P2P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W0_H`*.C1,$@A1GA$__<\
M^@%&&+$M2'A$__<V^RQ((49X1/_W,?H!1ABQ*DAX1/_W*_LI2"%&>$3_]R;Z
M`4:PL29(>$3_]R#[)4H12WI$TU@::`&;6D!/\``#%=$A22)(>41X1`*PO>AP
M0/_W#;L?2"%&>$3_]PCZ`48`*.30'$AX1/_W`?O?Y__W"NA^;@``&`$``(0;
M``!T;@``%`$``$@;```4&P``Y!H``+`:``"$&@``Y!D``!@:``#H&0``N!D`
M```9``!*&0``)AD``$@9``!0&0``4AD``'X8``"4:P``3!D``+(8```F&0``
ML!@```"U3_2`7*WK#`S,^/`/$TJ#L!-+:49Z1!)(>$336!MH`9-/\``#__>U
M^4"Q`'@`*!B_,"@,OP$@`""`\`$`"DH'2WI$TU@::`&;6D!/\``#`M$#L%WX
M!/O^]ZCOUFH``!@!```B&```JFH```^T3_2`7`"UK>L,#,SX\`_?^##`@[`,
M2@2K_$0+20Q(>41<^`(@$F@!DD_P``)3^`0K`),(6`$A`&C^]U#O_R#^]_3O
M9FH``!@!``!@:@``'`$``"WI\$=/\``,3_2`/JWK#`RLZPX.K/6`7,SX``#T
M1?G13O@X#*WU@#V&L#Y,`B$-]8`U?$04-0"1`"([20`C@$9A6`EH*6!/\``!
M_O=$[P$X8?$`!_H7@.H"`YL:F[)30)L:8NL"`L8:9^L"!P`O2]M/\`@)P/(!
M"0.M`"$R1CM&0$8`D?[W)N^Q\?\_"+^P\?\_0=!*1BE&0$;^][3N0QPVT`<H
M)MD(."P8(]+?^'R@^D0"X`$\K$(<TP@B448@1O[W2NX`*/719!N@&4?KY'$7
M2@WU@#042Q0T>D336!IH(VA:0$_P``,:T0WU@#T&L+WH\(>V]8`V9_$`![?Q
M_S\(OQ;U@#^XT4_P_S`!1M_G"$AX1/_W2O\'2'A$__=&__[WY.[Z:0``&`$`
M`+1J``!2:0``^A8``.(6```(M4_T@%RMZPP,S/CX#_[W3N[^]XKN`+$`:`B]
M\+5/](!<K>L,#,SXT`\F2H>P)DL%1GI$)4X$J7Y$TU@P1AMH!9-/\``#__>G
M^!"Q`W@$1HNY'TH<2WI$TU@::`6;6D!/\``#+-$;2"E&>$0'L+WH\$#_]Y&Y
M*$;^]T3N!T8@1O[W0.XX1`(P_O>,[A)+3_#_,@$A>T0!DQ!+`I0$1GM$`)7^
M]\KN#DH'2WI$TU@::`6;6D!/\``#!+\A1C!&U=#^]W;NOF@``!@!``"D%@``
MFF@``'(6``!8%0``4A4``$9H```MZ?!/3_2`7*WK#`S,^.`.W_@X%+^PW_@X
M5"2OW_@T)'E$?42"1@7Q#`,%\1@,*JPP-8I8)D8-\9P)W_@<M!)H/9)/\``"
M#?$@")/H!P"'Z`<`^T2\Z`\`#\:<Z`,`AN@#`)7H!P")Z`<`_$A!1GA$__<@
M^""Q`W@%1@`K0/!I@?[WHNW^]][M`"@`\)V`!F@`+@#PF8`P1O[WPNU```$P
M_O<.[C%X!48'D'FQW_BPD_E$*$8`D4M&`2%/\/\R`C7^]TCN%O@!'P`I\M'E
M2'A$`N!4^`0/B+%!1O[WZ_\%1@`H]M`#>``K\]#_]ROX`"COT"A&_O?2[01&
MB+E7^`1+=+$C>``K`/`/@2!&__<:^``H\]`@1O[WPNT$1@`H[=`@1O[W?NT'
MG09&*$;^]WCM!D0&\@1&,$;^]\+MRDL'1D_P_S)[1`*3R$L!(0.5>T0!D\=+
M`)1[1/[W_.U/].!Q.$;^]]+L`3`%T?[W+.X!:!$I0/#@@$%&.$;^]_SL!48`
M*#G0NTG:^``PNTI;^`$`>D0`EP$A`&C^]Y[M`":W2JQ+>D336!IH/9M:0$_P
M``-`\$:!,$8_L+WH\(_^]V[M!D8`*$#PLH!9^`0+6+%!1O[W</\`*/?0`W@`
M*^[16?@$"P`H\]&F3@T@_O=J[5,A!49^1`>06><,FP/T<$.S]8!/O]$.G/[W
MX.R$0KK1#)O#\P@#L_7@?[31,$;^]U#M!D:82$%&>$3^]T3_`48`*`#PH8#:
M^```__<F^H%&`"@`\)F`2$;^]^SL!$8#*`_9C4D$.$A$>43^]ZCM0+D$+`#P
MV8!,1!3X!3PO*P#PTX"&2$%&>$3^]QW_(+$#>#`K&+\`*P;1`"%(1O[WZ.P$
M1@`H<]%^27](>43?^/RA>$3?^/B1__<&^-_X]('^]SKM?$M/\/\R`2%[1`.3
M>DOZ1`"7^41[1,WI`3!X2S!&^$1[1/[W0.T3X/[W=.T#:!$K%M'^]R#M`36$
M1E-&(D8!(3!&S>D#6<WI`8P`E_[W*NU/].!Q,$;^]P#L!$9#'./0.$;^]V+L
M9D@Q1GA$_O?*_S!&__<)_CKG'$;YYO[W>.Q```$PM.9/2MKX`#!;^`(`S>D`
M<0$A6TH`:'I$_O?$["3G__?Q_5A*/DMZ1--8&F@]FUI`3_```VK1*$8_L+WH
M\$_^]Y&\VO@`D&/G__<P_8!&L?$`"87;L/$*`D_P``II\0`#($8-\<`+S?@`
MH/[WBNP&(EE&($;^]QSL!BA)T3":3_2&0\3R03.:0G_T:J^[^`0@1/)(4YI"
M?_1CK[CQ,@(@1FGQ``,RK<WX`*#^]VKL($8H(BE&_O?\ZR@H*=$R2P$A,DHP
M1GM$`9,Q2WI$`I4#DGM$3_#_,@"7C?CPH/[WH.Q\Y]KX!$``+#_T**\@1O[W
M_NL#*'_V(J\F200X($1Y1/[WNNP`*`B_H487Y_[W1.PA2'A$__>@_.QG```B
M:0``&`$``+IG``!^%```8!4``-H4``#@%```QA,``,(4```<`0``V!0``&IF
M```6%```EA0``&X4``#H$@``0!,``+X2``!"%```YA0``$82``#P%```4!(`
M`"`4``#2$0``XA(``+)D```<$0``JA,``-P2``":$@``CA(``'"U3_2`7*WK
M#`S,^.@/9$F"L&1*'>YP3WE$64MB2&Y&BEAX1&E&$F@!DD_P``)[1!MHY5B5
M^&@PA?AI,/[WTOT0L0-X,2M\T/_W+OI-2WM$&VCE6%5)*$8#(P$B>43^]R[K
M!49PL0)I1TM[1!MH$6A/2N!8>D3^]R[K*VD9:(MH6P)JU$%)`R,!(GE$"6A@
M6$A)>43^]Q+K!49XL49(,49X1/[WG_TK:0)&&6@`*$S0-TM[1!MHX%C^]PSK
M-4L!(CY)>T0;:'E$Y5@H1O[WTNH[2@%&*$9Z1#I-_O?\ZBY+.4A]1'M$&V@`
M(GA$,4;C6(/X:2#^]W;]!$:H8+"Q3_3@<2!&_O>8ZD(<`T81*!B_`2HKV"U*
M(TMZ1--8&F@!FUI`3_```Q_1`K!PO6AH__?__`1&J&``*.'1)4AX1/[WA.M#
M>``KA=!^YR)+"$9[1%MH&6C^]PK_L.<02WM$&VC@6/[W.NN-Y_[W2.L:22)&
M&DAY1'A$26@):/[W9NL`OQ9D``#V8P``VF,``+IC``"28P``@F,``&!C``#H
M8@``)&,``!@!``!.$```Z!$``-01``"^$0``B`\``(X1``"6$0``UF,``#(/
M```D8@``.!$``&IC``!&8P``)!$``#"U3_2`7*WK#`S,^.@/*4H$1BE+@[!Z
M1"A(:49X1--8&V@!DT_P``/^]^S\<+$#>#`K&+\`*PR_`2,`(X/P`0,`+`R_
M`",#\`$#6[D<2AI+>D336!IH`9M:0$_P``,GT0.P,+TC>``K\-`@1O_WGO@O
M(05&_O=$Z@"Q11PH1O[WMNH0200B>43^]Q+K`"C=T0U*"4MZ1--8&F@!FUI`
M3_```P71($8#L+WH,$#^]RZ]_O>TZD9A```8`0``D`X```QA``#N#@``R&``
M```````MZ?!/3_2`7*WK#`S,^#`-W_@02JWU*WT#1@BI`_&`!]_X!#I\1`*0
M"D9`,``FO$;C6!MHJ9-/\``#4.D"=%9@UF`0,C^Z0O@0?",*)0(#]']#"#!#
MZA1C!?1_!4/J!&.$14/J!0-"^`@\YM'=Z2*""JPFFPWQB`L`DR2H)JT!]0)S
M`Y`@1@25S>D%00UHS?@<L)-&W?B4X-WXG,`)G]WX+*`DGMWX*)``F0&3`>"1
M1II&`)$`(]#I#A10^`@O0V=10('J"`&P1D-H:4``GDU&7$"$Z@L$\T9\0.9&
M3^K1?$D83.I$#`&<0>H,`5=&3_``#*!"`6?:T0.;`IC=^!RP'6@$F]WI!4';
M^`!@&VC0Z0%[`Y/0Z0,ZT/@`P$_JFPX*:"%H3NJ#?H1I1_:9$\7V@B,`E`1J
MTAA/ZMQ@`91`ZD<0$AD`G$#J3!""&$[JBWZ*Z@0`3^J<"0#J"P!)ZH=Y8$!)
MZHQY$AB*Z@X`R1@`Z@P`"1G=^#"`@.H*``Z?"!B.Z@D!&.L#"!%``.OR8!CK
M"@B!Z@X!3^JR`ACK`0'_&!?K#@@!Z_!GB>H"`=WX0.`!0$_JL`"!Z@D!&.L!
M`1[K`PX>ZPD)`>OW;H+J``'=^$B`.4!/ZK<'44`9ZP$!&.L#"!CK`@F`Z@<"
MW?A0@`+J#@(!Z_YA0D!/ZKX.&>L"`ACK`P@8ZP`)`NOQ8(?J#@+=^%B`"D!/
MZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX8(`"0$_JL`""Z@X"&>L"`ACK
M`P@8ZPX)`NOW;H'J``+=^&B`.D!/ZK<'2D`9ZP("&.L#"!CK`0D"Z_YA@.H'
M`MWX<(`"Z@X"3^J^#D)`&>L"`ACK`P@8ZP`)`NOQ8(?J#@+=^'B`"D!/ZK$!
M>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX@(`"0$_JL`""Z@X"&>L"`ACK`P@8
MZPX.`NOW:('J``(Z0$_JMP=*0![K`@+V&'88@.H'`0'J"`$"Z_AB04!/ZK@(
M<1CM&"T8`>OR8(?J"`$10$_JL@)Y0(CJ`@9I&`.=!D`!Z_!A[!@HG4_JL`"&
MZ@@&Y!F"Z@`'I!GM&!7K"`8/0"J=!.OQ9%=`3^JQ`?89@.H!#NT8#NH$#J\8
M+)U/ZK0"CNH`#@;K]&87ZPX$@>H"!^T8+1@W0"Z83T`$Z_9D[QE/ZK8&PQA;
M&(+J!@$A0#"=44`'Z_1N6!A.]J$SQO;98T_JM`05ZP,(,ID8ZP((ANH$`@#K
M_F""Z@X"3^J^!1CK`@B$Z@4.RA@TGPCK\&&.Z@`.DAE/ZK``$NL.`C:>_QB%
MZ@`.`NOQ8H[J`0X\&4_JL0$4ZPX$.)_V&(#J`0X$Z_)DCNH"#G493^JR`A7K
M#@4ZGH'J`@[_&([J!`X_&`7K]&`7ZPX'3^JT!!;K`PX\G1[K`0X'Z_!A@NH$
M!SZ>1T!/ZK``'NL'#N\8OQ@.Z_%BA.H`#D"=CNH!#D_JL0$7ZPX'%NL##A[K
M!`X'Z_)D@.H!!T*>5T!/ZK("'NL'#N\8/Q@.Z_1@@>H"#D2=CNH$#D_JM`07
MZPX'@NH$#O88!^OP9X[J``YV&$_JL``6ZPX&1IF$Z@`.[1@&Z_=FCNH'#JT8
M3^JW!Q7K#@5(FLD8@.H'#@7K]F6.Z@8.#!E/ZK8&%.L.!$J9TAB'Z@8.!.OU
M9([J!0X0&$_JM040ZPX`3)J&Z@4.R1@`Z_1@CNH$#LD93^JT!!'K#@%.GX7J
M!`[2&`'K\&&.Z@`.DAE/ZK``$NL.`E">_QB$Z@`.`NOQ8H[J`0Y]&4_JL0$5
MZPX%4I_V&(#J`0XT&8[J`@X%Z_)F%.L.!$_JL@(7ZP,.5)T>ZP`.@>H"`'!`
M!.OV9![K``Y/ZK8`[1B"Z@`&:1A6G69`#NOT;HD93^JT!.L86)V;&(#J!`*"
MZ@X"3^J^!YH82_;<0\CV&W,!Z_YA[1A$Z@<.6IXH&`[J`0X$Z@<%3NH%#@+K
M\6(0ZPX.3^JQ`?`87)T`&4?J`00.Z_)F%$`'Z@$.3^JR`D3J#@0!Z@(()!CM
M&$'J`@`5ZP<.,$`$Z_9E7IQ`Z@@`3^JV!A#K#@[@&`[K]61`&$+J!@$"Z@8.
M*4!@GT'J#@%/ZK4%"1@!Z_1@_QA&Z@4!!NH%#KH8(4!BGT_JM`1!Z@X!!>H$
M"(D8_QA%Z@0"%^L&#@)`9)\!Z_!A0NH(`D_JL``2ZPX"_Q@$Z@`.?1D"Z_%G
M1.H``F:>"D!/ZK$!0NH.`MWXH.%5&?(8$AE`Z@$$3^JW!@7K]V4\0`#J`0<\
M0T'J!@>B&![K`P0D&`'J!@YJF"]``NOU8D?J#@=/ZK4%/!E&Z@4'P!@$Z_)D
M!NH%#D`8%T!/ZK(!;)I'Z@X'/QA%Z@$`TA@@0)(9!^OT9@7J`0=/ZK0$.$-!
MZ@0'@!ANF@'J!`XW0-(8`.OV8%49<)I'Z@X'3^JV!G\9TAA5&`?K\&%$Z@8'
M!.H&#G*:!T!'Z@X'3^JP`'T9TA@2&4;J``0&Z@`'#$`\0P7K\66D&'2:3^JQ
M`03K]632&$#J`0<`Z@$.EADO0'::1^H.!T_JM06_&=(8%A@'Z_1@0>H%!P'J
M!0YXFB=`1^H.!T_JM`2_&47J!`;2&`9`4A@'Z_!A!>H$!T_JL``^0P*?MA@`
M(@3J``X&Z_%F>F#Z8'J:TAA5&0`B>F'Z843J``=\F@]`1^H.!T_JL0%_&=(8
M0.H!!0?K]F<2ZP0.-4!/ZK8$?IH`Z@$&-4,!Z@0&%>L.!=,8&QA!Z@0`.$"`
MFC!#!>OW9<`83/+6$\SV8B-/ZK<'UAB"FG88A.H'`6E``.OU8'883^JU!=(8
MA^H%`109A)I!0`;K\&9D&$_JL`#2&(7J``'7&8::!.OV9'%`?QA/ZK8&T1B(
MFDD9!^OT98#J!@=G0$_JM`3)&=<8/QB*FH;J!``!Z_5A:$!/ZK4%/QC0&(`9
MC)H'Z_%FA.H%!T]`3^JQ`<`9UQ@_&8Z:A>H!!`#K]F!T0#\93^JV!-88D)IV
M&0?K\&6!Z@0'1T!/ZK``]AG7&'\8DIH&Z_5AA.H`!FY`3^JU!;\9UA@V&92:
M!^OQ9(#J!0=/0$_JL0'V&=<8/QB6F@;K]&"%Z@$&9D!/ZK0$OQG6&'89F)H'
MZ_!E@>H$!T=`3^JP`/89UQA_&)J:!NOU883J``9N0$_JM06_&=88-AF<F@?K
M\62`Z@4'3T!/ZK$!]AG7&#\8GIH&Z_1@A>H!!F9`3^JT!+\9UAAV&:":!^OP
M98'J!`='0$_JL`#V&=(85Q@&Z_5AHIJ$Z@`&;D!/ZK4%OQG2&!89!^OQ9(#J
M!0>DFD]`3^JQ`?<9`IX'Z_1GTA@0&`KKMP(R8:::A>H!!F9`3^JT!(`9TQB!
MZ@0"`.OW8'I`$^L,`P*?6QF;&!#K"P(#Z_!C`)@[8`&;)!BZ8``B>F+)&`M*
M"4MZ1+QA.6+36!IHJ9M:0$_P``,#T0WU*WV]Z/"/_?>6[0"_:&```!@!``"*
M5@``"+5/](!<K>L,#,SX^`^`(/WW?NV?[0Y[`"*"9X#M`'N?[0U[@.T">Y_M
M#7N`[01[G^T->X#M!GN?[0U[@.T(>Y_M#7N`[0I[@.T,>PB]`+\!(T5G````
M`(FKS>\`````_MRZF`````!V5#(0`````/#ATL,````````````````MZ?!'
M3_2`7*WK#`S,^.`/!4:`:A9&`",/1@#KQ@ST%X1%Z&K5Z0PA<^L```+2`3)!
M\0`!J&\%\3@*Q>D*PW,/0^K$`YL8*V-!ZU1Q:6.HNS\N*]VF\4`(M@D&\?\Y
M/$8'ZX86(T921@3Q0`'3^`#`$#-3^`Q,$#)3^`@,4_@$[(M"0O@$[$+X$,Q"
M^`Q,0O@(#.O1'$8H1O_W6OJT0N'10#>HZXD6*/`_"$=$,D8Y1E!&_?>J[*YG
MO>CPA\#Q0`0%\3@*M$)01*B_-$8Y1B)&_?>:[*MO(T2K9T`K[-$H1C8;)T3_
M]S3ZLN<`ORWI\$%/](!<K>L,#,SXZ`^+:@'Q.`<.:PQ&D_J#^`5&P_/%`X`A
M6APVNK@8."KY5$3=PO%``@`A_?<@["!&__<1^CA&."(`(?WW&.P@1L3I'&C_
M]P?ZXW@K<"!&8XAK<"-H&PJK<"-HZW#C>BMQ8XEK<:-H&PJK<:-HZW'C?"MR
M8XIK<B-I&PJK<B-IZW+C?BMS8XMK<Z-I&PJK<Z-IZW.4^",P*W1CC&MT(VH;
M"JMT(VKK=+WH\$']]_Z[PO$X`@`A_??<Z\'G`DM[1!MH_?>-O`"_6E4```A`
M+>D(@+WH`0`"`#X```!!````#````$$````1````00```"<```!!````-@``
M`$$````#````00````8```!!````%0```$$````/````00````X```!!````
M)@```$$````3````00```"D```!!`````@```$$````9````00````H```!!
M````"P```$$``````````````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y
M;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/
M5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]04D]'
M3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````4$523$Q)0@!0
M15),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/
M0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````,0```&QS965K
M(&9A:6QE9`````!R96%D(&9A:6QE9`!,1%],24)205)97U!!5$@`4UE35$5-
M```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E
M(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42```
M``!P87)L`````"YP87(`````<VAO<G0@<F5A9```)7,E<V-A8VAE+25S)7,`
M`"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````!@```!P97)L
M`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V,P```%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`````+64``"TM``!54T52`````%5315).04U%`````%1%35!$25(`
M5$U0`"]T;7``````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F
M<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'
M24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C
M('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)
M0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H
M)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U
M9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H
M)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@
M82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2![
M"G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I
M>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H
M)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*
M?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A
M<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%
M3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T
M96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI
M.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@
M.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H
M+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`]
M(&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@
M/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]
M/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP
M+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@
M7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M
M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP
M<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP
M.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE
M(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P
M87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@
M)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/
M3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"![
M"E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-
M4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@
M(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S
M971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M
M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0
M?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%2
M3E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R
M;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G
M;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@
M17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P
M87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q
M6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE
M("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2
M(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(
M12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF
M("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO
M=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO
M=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L
M("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K
M*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S
M(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O
M9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I
M;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B
M=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F
M:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@
M(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\
M7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M
M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP
M;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C
M<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN
M86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO
M9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O
M)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/
M.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL
M92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB
M:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K
M*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?
M<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN
M9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L
M("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@
M)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"
M4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U
M:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)
M4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E
M8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD
M<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@
M<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L
M92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?
M4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P
M<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A
M<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@
M("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P
M87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A
M;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6
M>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R
M;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%2
M1U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@
M;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS
M:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B
M)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*
M)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T
M(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T[
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R
M(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R
M<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P
M87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD
M;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L
M("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@
M(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@
M<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D
M4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T
M(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*
M<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@
M96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II
M9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A
M?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD
M9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO
M861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!0
M05(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN
M:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![
M("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D
M7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L
M('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK
M(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E
M24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@
M("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X[
M"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I
M;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@
M)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D
M:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@
M/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O
M6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q
M?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@
M*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L
M("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE
M.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I
M;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R
M:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F
M:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D
M9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO
M8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@
M/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L
M>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G
M3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R
M8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=
M.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I
M('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F
M("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN
M="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA
M;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H
M+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD
M8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A
M8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H
M("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#
M2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D
M97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)
M0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE
M<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I[
M"FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M
M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/
M.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I
M;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D
M>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B
M17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@
M;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E
M<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I
M;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H
M;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*
M)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^
M=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB
M97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA
M;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14
M;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@
M(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/
M(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D
M,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N
M<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=
M('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D
M,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M
M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A
M=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@
M9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I
M<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*
M<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R
M<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N
M9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*
M979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R
M.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!]
M.PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L
M87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T
M96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]
M"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0
M("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED
M.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^
M.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R
M;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY
M("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I
M<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L
M("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@
M)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I
M*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T
M7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D
M9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#
M04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?
M<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@
M,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@
M<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E
M("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP
M+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y
M<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L
M("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE
M(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F
M=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M
M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H
M*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC
M:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M
M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D[
M"GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA
M;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B
M<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES
M>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI
M<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!]
M.PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S
M="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*
M?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N
M86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W
M9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN
M,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE
M(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*
M9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)0
M05)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.
M5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID
M96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`
M````0T%#2$4``#X```!!````#````$$````1````00```"<```!!````-@``
M`$$````#````00````8```!!````%0```$$````/````00````X```!!````
M)@```$$````3````00```"D```!!`````@```$$````9````00````H```!!
M````"P```$$``````````````,29_W\!````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!Q%P``,1<```$````C`P```0```#,#```!````
M/0,```P```"H$0``#0```+0Z```9````P(T``!L````$````&@```,2-```<
M````!````/7^_V^T`0``!0```"`)```&````H`(```H```"X!```"P```!``
M```5``````````,```#0C@```@```-@!```4````$0```!<```#0#P``$0``
M`/@.```2````V````!,````(````'@````@```#[__]O`0``"/[__V^H#@``
M____;P(```#P__]OV`T``/K__V\.````````````````````````````````
M`````````````````````````,B-`````````````+01``"T$0``M!$``+01
M``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$`
M`+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``
MM!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T
M$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01
M``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``````
M````````````````````````````````````````````````````````````
M`````*$4````````!)````I005(N<&T*`````)@^``"L.P```````&P\``!P
M/```C#X``+0[``"4/@```````'@^``"`/@```````*`^``!'0T,Z("A$96)I
M86X@,30N,BXP+38I(#$T+C(N,`!!,@```&%E86)I``$H````!3<M00`&"@=!
M"`$)`@H$$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-
M+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S
M``````````````````````````````````````````````````````````L`
M```!`````@```%0!``!4`0``&0```````````````0`````````3````!P``
M``(```!P`0``<`$``"0```````````````0`````````)@````<````"````
ME`$``)0!```@```````````````$`````````#0```#V__]O`@```+0!``"T
M`0``[`````4`````````!`````0````^````"P````(```"@`@``H`(``(`&
M```&`````P````0````0````1@````,````"````(`D``"`)``"X!```````
M```````!`````````$X```#___]O`@```-@-``#8#0``T`````4`````````
M`@````(```!;````_O__;P(```"H#@``J`X``%`````&`````@````0`````
M````:@````D````"````^`X``/@.``#8````!0`````````$````"````',`
M```)````0@```-`/``#0#P``V`$```4````5````!`````@```!\`````0``
M``8```"H$0``J!$```P```````````````0`````````=P````$````&````
MM!$``+01``#H`@`````````````$````!````((````!````!@```*`4``"@
M%```%"8`````````````"`````````"(`````0````8```"T.@``M#H```@`
M``````````````0`````````C@````$````"````O#H``+PZ``#X00``````
M```````$`````````)8````!``!P@@```+1\``"T?```"`````T`````````
M!`````````"A`````0````(```"\?```O'P```0```````````````0`````
M````JP````X````#````P(T``,!]```$```````````````$````!````+<`
M```/`````P```,2-``#$?0``!```````````````!`````0```##````!@``
M``,```#(C0``R'T```@!```&``````````0````(````S`````$````#````
MT(X``-!^```P`0`````````````$````!````-$````!`````P````"0````
M@```2```````````````!`````````#7````"`````,```!(D```2(```!0`
M``````````````0`````````W`````$````P`````````$B````>````````
M```````!`````0```.4````#``!P``````````!F@```,P``````````````
M`0`````````!`````P``````````````F8```/4```````````````$`````
#````
